@@ -26,6 +26,13 @@ class AnsiblePlaybook(object):
         self._hosts = set()
         self._cleanup_output = cleanup_output
 
+        hosts = self._get_hosts_by_group(
+            self._ansible_playbook_inventory,
+            'all'
+        )
+
+        self._hosts.add(*hosts)
+
         LOGGER.info('Output path: {0}'.format(self._path_str))
         LOGGER.info('CWD: {0}'.format(self._ansible_playbook_directory))
 
@@ -69,17 +76,15 @@ class AnsiblePlaybook(object):
 
         return ansible_command
 
-    def _get_hosts_by_group(self, inventory, group, some_playbook):
+    def _get_hosts_by_group(self, inventory, group):
         get_hosts_by_group_cmd = [
-            "ansible-playbook",
+            "ansible",
             "--timeout",
             "60",
-            '--list-hosts',
             "-i",
             inventory,
-            some_playbook,
-            '-e',
-            '{0}={1}'.format('play_host_groups', group)
+            '--list-hosts',
+            group
         ]
 
         result = subprocess.run(
@@ -107,7 +112,9 @@ class AnsiblePlaybook(object):
 
             i = i + 1
 
-        if i == len(tmp):
+        # ignore the full line "hosts (#):"
+        i = i + 1
+        if i >= len(tmp):
             raise RuntimeError(
                 'No hosts were found for group: {0}'.format(group)
             )
@@ -120,8 +127,6 @@ class AnsiblePlaybook(object):
     def run_playbook(self, play_filename, extra_vars_dict=None):
         if not extra_vars_dict:
             extra_vars_dict = {}
-        if 'play_host_groups' not in extra_vars_dict:
-            extra_vars_dict['play_host_groups'] = 'localhost'
 
         local_extra_vars = copy.deepcopy(extra_vars_dict)
         local_extra_vars['output_path'] = self._path_str
@@ -129,6 +134,8 @@ class AnsiblePlaybook(object):
             local_extra_vars['skip_errors'] = False
         if 'gather_facts_for_pb' not in local_extra_vars:
             local_extra_vars['gather_facts_for_pb'] = False
+        if 'play_host_groups' not in local_extra_vars:
+            local_extra_vars['play_host_groups'] = 'localhost'
 
         cmd = self._get_ansible_cmd(
             self._ansible_playbook_inventory,
@@ -136,20 +143,6 @@ class AnsiblePlaybook(object):
                 self._ansible_playbook_directory, play_filename),
             extra_vars_dict=local_extra_vars)
 
-        hosts = self._get_hosts_by_group(
-            self._ansible_playbook_inventory,
-            extra_vars_dict['play_host_groups'],
-            '{0}/{1}'.format(
-                self._ansible_playbook_directory,
-                '_dummy_playbook.yml'
-            ),
-        )
-
-        if '(1):' in hosts:
-            hosts.remove('(1):')
-
-        self._hosts.add(*hosts)
-
         for host in self._hosts:
             file_path = '{0}/{1}.json'.format(self._path_str, host)
             if not os.path.isfile(file_path):
@@ -171,8 +164,7 @@ class AnsiblePlaybook(object):
                 stderr=subprocess.STDOUT,
             )
 
-            if 'skip_errors' not in extra_vars_dict or \
-                    not extra_vars_dict['skip_errors']:
+            if not local_extra_vars['skip_errors']:
                 if result.returncode != 0:
                     LOGGER.info(
                         'Failed to run:\n{0}'.format(' '.join(cmd))
